@@ -1,13 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 
 #include <MailImporter/FilterImporterBase>
-#include <QVector>
+#include <QList>
 struct FilterImporterData {
     QString folderName;
     QString msgPath;
@@ -27,8 +27,8 @@ public:
     QString topLevelFolder() const override;
 
     bool importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone) override;
-    QVector<FilterImporterData> filterImporterDataList() const;
+    QList<FilterImporterData> filterImporterDataList() const;
 
 private:
-    QVector<FilterImporterData> mFilterImporterDataList;
+    QList<FilterImporterData> mFilterImporterDataList;
 };
